==> guile-2.0.9-i486-1.txz: usr/lib/guile/2.0/ccache/rnrs/enums.go <==
GOOF----LE-4-2.01%      ]  4  h,      ] g  guile	 	g  define-module*	 	 	g  rnrs	g  enums	 		g  filenameS	
f  rnrs/enums.scm	g  pureS	g  versionS	
	 	g  set-current-module	 	 	g  resolve-r6rs-interface	 	 	g  only	g  and=>	 	g  call-with-deferred-observers	 	 	g  module-use-interfaces!	 	 	g  current-module	 	 	 g  base	! 
 	"g  
conditions	#"
 	$g  
exceptions	%$
 	&g  records	'g  
procedural	(&'
 	)g  syntax-case	*)
 	+g  srfi	,g  :1	-+, 	.g  module-export!	/. 	0. 	1g  define-enumeration	2g  enum-set-projection	3g  enum-set-complement	4g  enum-set-difference	5g  enum-set-intersection	6g  enum-set-union	7g  
enum-set=?	8g  enum-set-subset?	9g  enum-set-member?	:g  enum-set->list	;g  enum-set-constructor	<g  enum-set-indexer	=g  enum-set-universe	>g  make-enumeration	?123456789:;<=> 	@g  module-re-export!	A@ 	B@ 	Cg  module-replace!	DC 	EC 	Fg  make-record-type-descriptor	Gg  enum-set	Hg  mutable	Ig  universe	JHI 	Kg  	immutable	Lg  set	MKL 	NJM 	Og  enum-set-rtd	Pg  record-constructor	Qg  "make-record-constructor-descriptor	Rg  
make-enum-set	Sg  record-accessor	Tg  enum-set-universe-internal	Ug  record-mutator	Vg  enum-set-universe-set!	Wg  enum-set-set	Xg  length	Yg  memq	Zg  	list-copy	[g  lset-intersection	\g  eq?	]g  lset<=	^g  
lset-union	_g  raise	`g  make-assertion-violation	ag  lset-difference	bg  make-syntax-transformer	cb 	db 	eg  macro	fg  $sc-dispatch	gf 	hf 	ig  any	jg  each-any	kiiji 	lg  
syntax-object	mg  begin	ng  top	on 	pg  ribcage	qg  dummy	rg  	type-name	sg  symbol	tg  constructor-syntax	uqrst 	vg  m-fHHUs8UDDEwgPjyZXYO8nh-2375	wvn 	xwooo 	yf  l-fHHUs8UDDEwgPjyZXYO8nh-2380	zf  l-fHHUs8UDDEwgPjyZXYO8nh-2381	{f  l-fHHUs8UDDEwgPjyZXYO8nh-2382	|f  l-fHHUs8UDDEwgPjyZXYO8nh-2383	}yz{| 	~pux} 	p  g  x   w  f  l-fHHUs8UDDEwgPjyZXYO8nh-2377   p  o~  g  private   lm  g  
define-syntax l  g  lambda l  g  s l    l)  g  sym l    g  if l  lY  g  
syntax->datum l  g  syntax l      g  quote l      g  syntax-violation l  g  symbol->string l  f  not a member of the set l  l    g  _ l  g  ... l    g  let* l  lI  g  syms l          g  quoted-universe l  g  
datum->syntax l  g  list l          g  quoted-syms l          g  or l  g  every l  l          f  not a subset of the universe l    g  quasisyntax l  l;  l>  g  unsyntax l                    f  -source expression failed to match any patternC 5       hx    ]4	

5 4 >  "  G   45 4 h   @   ] 45 L  68       g  filenamef  rnrs/enums.scm
	
 		
   C O >  "  G   4!5 4       h   @   ] 45 L  68       g  filenamef  rnrs/enums.scm
	
 		
   C O >  "  G   4#5 4       h   @   ] 45 L  68       g  filenamef  rnrs/enums.scm
	
 		
   C O >  "  G   4%5 4       h   @   ] 45 L  68       g  filenamef  rnrs/enums.scm
	
 		
   C O >  "  G   4(5 4       h   @   ] 45 L  68       g  filenamef  rnrs/enums.scm
	
 		
   C O >  "  G   4*5 4       h   @   ] 45 L  68       g  filenamef  rnrs/enums.scm
	
 		
   C O >  "  G   4-5 4       h   @   ] 45 L  68       g  filenamef  rnrs/enums.scm
	
 		
   C O >  "  G   40?      h   @   ] 45 6   8       g  filenamef  rnrs/enums.scm
	
 		
   C>  "  G  4B        h   @   ] 45 6    8       g  filenamef  rnrs/enums.scm
	
 		
   C>  "  G  4E        h   @   ] 45 6    8       g  filenamef  rnrs/enums.scm
	
 		
   C>  "  G  4FiGN5OR4Pi4QiOi55RR4SiOi
5TR4UiOi
5VR4SiOi5WRRV     h      ]	4 56           g  symbol-list
		 g  es	
	  g  filenamef  rnrs/enums.scm
	-	 		  g  nameg  make-enumeration C>RT        h      ]	4 5$  C C |       g  enum-set
		 g  t			  g  filenamef  rnrs/enums.scm
	1	 		  g  nameg  enum-set-universe C=R:=XYX       h   -   ]L 4 5C   %       g  probe
		
  		
   C        h   )   ]4 L5L O 6  !       g  x
		  		   C    h(      ]44 5545O C            g  enum-set
		# g  symbols		# g  cardinality			#  g  filenamef  rnrs/enums.scm
	5	 		#  g  nameg  enum-set-indexer C<RR=Z        h   3   ]4L 54 56    +       g  symbol-list
		  		   C  h   y   ] O C      q       g  enum-set
		
  g  filenamef  rnrs/enums.scm
	<	 		
  g  nameg  enum-set-constructor C;R[\W=        h    s   ]44 554 56     k       g  enum-set
		  g  filenamef  rnrs/enums.scm
	A	 		  g  nameg  enum-set->list C:RYW  h      ]4 455$  CC       g  symbol
		 g  enum-set		  g  filenamef  rnrs/enums.scm
	F	 			  g  nameg  enum-set-member? C9R]\W=        h@      ]444 5544555$  4 5456C            g  
enum-set-1
		; g  
enum-set-2		;  g  filenamef  rnrs/enums.scm
	I	 		;	  g  nameg  enum-set-subset? C8R8        h       ]4 5$   6C              g  
enum-set-1
		 g  
enum-set-2		  g  filenamef  rnrs/enums.scm
	O	 			  g  nameg  
enum-set=? C7R=R^\W_`  h@      ]4 545$   4 544 5455645 6         g  
enum-set-1
		> g  
enum-set-2		>  g  filenamef  rnrs/enums.scm
	S	 		>	  g  nameg  enum-set-union C6R=R[\W_`      h@      ]4 545$   4 544 5455645 6         g  
enum-set-1
		> g  
enum-set-2		>  g  filenamef  rnrs/enums.scm
	\	 		>	  g  nameg  enum-set-intersection C5R=Ra\W_`       h@      ]4 545$   4 544 5455645 6         g  
enum-set-1
		> g  
enum-set-2		>  g  filenamef  rnrs/enums.scm
	e	 		>	  g  nameg  enum-set-difference C4R=Ra\:W   h(      ]	4 54454 556         g  enum-set
		& g  universe			&  g  filenamef  rnrs/enums.scm
	n	 		&  g  nameg  enum-set-complement C3RR=[\W:        h(      ]4544 5445556        g  
enum-set-1
		' g  
enum-set-2		'  g  filenamef  rnrs/enums.scm
	t	 		'	  g  nameg  enum-set-projection C2R4d1ehk     h   }   ]	
  
         
        C u       g  dummy
	  g  	type-name	  g  symbol		  g  constructor-syntax		   	 	   C    h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  		"  g  
macro-typeg  syntax-rulesg  patternsg  	type-nameg  symbolg  ... g  constructor-syntax   C51RCw      g  m
		+ g  iface
	2  g  iface
 5 g  iface
< g  iface
E g  iface
L g  iface
U g  iface
\  g  filenamef  rnrs/enums.scm		
W	 	n	$	}	(		)		+	R	-		1		5			<	
F	A	
	F		I		O	
	S		\		e	X	n	5	t	 	x
   C6 

==> guile-2.0.11-i486-2.txz: usr/lib/guile/2.0/ccache/rnrs/enums.go <==
GOOF----LE-4-2.01%      ]  4  h,      ] g  guile	 	g  define-module*	 	 	g  rnrs	g  enums	 		g  filenameS	
f  rnrs/enums.scm	g  pureS	g  versionS	
	 	g  set-current-module	 	 	g  resolve-r6rs-interface	 	 	g  only	g  and=>	 	g  call-with-deferred-observers	 	 	g  module-use-interfaces!	 	 	g  current-module	 	 	 g  base	! 
 	"g  
conditions	#"
 	$g  
exceptions	%$
 	&g  records	'g  
procedural	(&'
 	)g  syntax-case	*)
 	+g  srfi	,g  :1	-+, 	.g  module-export!	/. 	0. 	1g  define-enumeration	2g  enum-set-projection	3g  enum-set-complement	4g  enum-set-difference	5g  enum-set-intersection	6g  enum-set-union	7g  
enum-set=?	8g  enum-set-subset?	9g  enum-set-member?	:g  enum-set->list	;g  enum-set-constructor	<g  enum-set-indexer	=g  enum-set-universe	>g  make-enumeration	?123456789:;<=> 	@g  module-re-export!	A@ 	B@ 	Cg  module-replace!	DC 	EC 	Fg  make-record-type-descriptor	Gg  enum-set	Hg  mutable	Ig  universe	JHI 	Kg  	immutable	Lg  set	MKL 	NJM 	Og  enum-set-rtd	Pg  record-constructor	Qg  "make-record-constructor-descriptor	Rg  
make-enum-set	Sg  record-accessor	Tg  enum-set-universe-internal	Ug  record-mutator	Vg  enum-set-universe-set!	Wg  enum-set-set	Xg  length	Yg  memq	Zg  	list-copy	[g  lset-intersection	\g  eq?	]g  lset<=	^g  
lset-union	_g  raise	`g  make-assertion-violation	ag  lset-difference	bg  make-syntax-transformer	cb 	db 	eg  macro	fg  $sc-dispatch	gf 	hf 	ig  any	jg  each-any	kiiji 	lg  
syntax-object	mg  begin	ng  top	on 	pg  ribcage	qg  dummy	rg  	type-name	sg  symbol	tg  constructor-syntax	uqrst 	vg  m-qFQyrMToVSG6IU239lcMNn-2301	wvn 	xwooo 	yf  l-qFQyrMToVSG6IU239lcMNn-2306	zf  l-qFQyrMToVSG6IU239lcMNn-2307	{f  l-qFQyrMToVSG6IU239lcMNn-2308	|f  l-qFQyrMToVSG6IU239lcMNn-2309	}yz{| 	~pux} 	p  g  x   w  f  l-qFQyrMToVSG6IU239lcMNn-2303   p  o~  g  private   lm  g  
define-syntax l  g  lambda l  g  s l    l)  g  sym l    g  if l  lY  g  
syntax->datum l  g  syntax l      g  quote l      g  syntax-violation l  g  symbol->string l  f  not a member of the set l  l    g  _ l  g  ... l    g  let* l  lI  g  syms l          g  quoted-universe l  g  
datum->syntax l  g  list l          g  quoted-syms l          g  or l  g  every l  l          f  not a subset of the universe l    g  quasisyntax l  l;  l>  g  unsyntax l                    f  -source expression failed to match any patternC 5       hx    ]4	

5 4 >  "  G   45 4 h   @   ] 45 L  68       g  filenamef  rnrs/enums.scm
	
 		
   C O >  "  G   4!5 4       h   @   ] 45 L  68       g  filenamef  rnrs/enums.scm
	
 		
   C O >  "  G   4#5 4       h   @   ] 45 L  68       g  filenamef  rnrs/enums.scm
	
 		
   C O >  "  G   4%5 4       h   @   ] 45 L  68       g  filenamef  rnrs/enums.scm
	
 		
   C O >  "  G   4(5 4       h   @   ] 45 L  68       g  filenamef  rnrs/enums.scm
	
 		
   C O >  "  G   4*5 4       h   @   ] 45 L  68       g  filenamef  rnrs/enums.scm
	
 		
   C O >  "  G   4-5 4       h   @   ] 45 L  68       g  filenamef  rnrs/enums.scm
	
 		
   C O >  "  G   40?      h   @   ] 45 6   8       g  filenamef  rnrs/enums.scm
	
 		
   C>  "  G  4B        h   @   ] 45 6    8       g  filenamef  rnrs/enums.scm
	
 		
   C>  "  G  4E        h   @   ] 45 6    8       g  filenamef  rnrs/enums.scm
	
 		
   C>  "  G  4FiGN5OR4Pi4QiOi55RR4SiOi
5TR4UiOi
5VR4SiOi5WRRV     h      ]	4 56           g  symbol-list
		 g  es	
	  g  filenamef  rnrs/enums.scm
	-	 		  g  nameg  make-enumeration C>RT        h      ]	4 5$  C C |       g  enum-set
		 g  t			  g  filenamef  rnrs/enums.scm
	1	 		  g  nameg  enum-set-universe C=R:=XYX       h   -   ]L 4 5C   %       g  probe
		
  		
   C        h   )   ]4 L5L O 6  !       g  x
		  		   C    h(      ]44 5545O C            g  enum-set
		# g  symbols		# g  cardinality			#  g  filenamef  rnrs/enums.scm
	5	 		#  g  nameg  enum-set-indexer C<RR=Z        h   3   ]4L 54 56    +       g  symbol-list
		  		   C  h   y   ] O C      q       g  enum-set
		
  g  filenamef  rnrs/enums.scm
	<	 		
  g  nameg  enum-set-constructor C;R[\W=        h    s   ]44 554 56     k       g  enum-set
		  g  filenamef  rnrs/enums.scm
	A	 		  g  nameg  enum-set->list C:RYW  h      ]4 455$  CC       g  symbol
		 g  enum-set		  g  filenamef  rnrs/enums.scm
	F	 			  g  nameg  enum-set-member? C9R]\W=        h@      ]444 5544555$  4 5456C            g  
enum-set-1
		; g  
enum-set-2		;  g  filenamef  rnrs/enums.scm
	I	 		;	  g  nameg  enum-set-subset? C8R8        h       ]4 5$   6C              g  
enum-set-1
		 g  
enum-set-2		  g  filenamef  rnrs/enums.scm
	O	 			  g  nameg  
enum-set=? C7R=R^\W_`  h@      ]4 545$   4 544 5455645 6         g  
enum-set-1
		> g  
enum-set-2		>  g  filenamef  rnrs/enums.scm
	S	 		>	  g  nameg  enum-set-union C6R=R[\W_`      h@      ]4 545$   4 544 5455645 6         g  
enum-set-1
		> g  
enum-set-2		>  g  filenamef  rnrs/enums.scm
	\	 		>	  g  nameg  enum-set-intersection C5R=Ra\W_`       h@      ]4 545$   4 544 5455645 6         g  
enum-set-1
		> g  
enum-set-2		>  g  filenamef  rnrs/enums.scm
	e	 		>	  g  nameg  enum-set-difference C4R=Ra\:W   h(      ]	4 54454 556         g  enum-set
		& g  universe			&  g  filenamef  rnrs/enums.scm
	n	 		&  g  nameg  enum-set-complement C3RR=[\W:        h(      ]4544 5445556        g  
enum-set-1
		' g  
enum-set-2		'  g  filenamef  rnrs/enums.scm
	t	 		'	  g  nameg  enum-set-projection C2R4d1ehk     h   }   ]	
  
         
        C u       g  dummy
	  g  	type-name	  g  symbol		  g  constructor-syntax		   	 	   C    h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  		"  g  
macro-typeg  syntax-rulesg  patternsg  	type-nameg  symbolg  ... g  constructor-syntax   C51RCw      g  m
		+ g  iface
	2  g  iface
 5 g  iface
< g  iface
E g  iface
L g  iface
U g  iface
\  g  filenamef  rnrs/enums.scm		
W	 	n	$	}	(		)		+	R	-		1		5			<	
F	A	
	F		I		O	
	S		\		e	X	n	5	t	 	x
   C6 
